@@ -15,13 +15,21 @@ final class ObjectClass extends Attribute
 	// The schema ObjectClasses for this objectclass of a DN
 	protected Collection $oc_schema;
 
-	public function __construct(string $name,array $values)
+	/**
+	 * Create an ObjectClass Attribute
+	 *
+	 * @param string $dn DN this attribute is used in
+	 * @param string $name Name of the attribute
+	 * @param array $values Current Values
+	 * @param array $oc The objectclasses that the DN of this attribute has
+	 */
+	public function __construct(string $dn,string $name,array $values,array $oc=[])
 	{
-		parent::__construct($name,$values);
+		parent::__construct($dn,$name,$values,['top']);
 
 		$this->oc_schema = config('server')
 			->schema('objectclasses')
-			->filter(fn($item)=>$this->values->contains($item->name));
+			->filter(fn($item)=>$this->values->merge($this->values_old)->unique()->contains($item->name));
 	}
 
 	public function __get(string $key): mixed
