@@ -11,8 +11,8 @@ trait MD5Updates
 {
 	public function isDirty(): bool
 	{
-		foreach ($this->values->diff($this->oldValues) as $key => $value)
-			if (md5(Arr::get($this->oldValues,$key)) !== $value)
+		foreach ($this->values->diff($this->values_old) as $key => $value)
+			if (md5(Arr::get($this->values_old,$key)) !== $value)
 				return TRUE;
 
 		return FALSE;
