@@ -2,7 +2,7 @@
 <!-- $o=Binary\JpegPhoto::class -->
 <x-attribute.layout :edit="$edit" :new="false" :o="$o">
 	<table class="table table-borderless p-0 m-0">
-		@foreach (($old ? $o->old_values : $o->values) as $value)
+		@foreach ($o->values_old as $value)
 			<tr>
 				@switch ($x=$f->buffer($value,FILEINFO_MIME_TYPE))
 					@case('image/jpeg')
@@ -14,7 +14,7 @@
 							@if ($edit)
 								<br>
 								<!-- @todo TO IMPLEMENT -->
-								<span class="btn btn-sm btn-danger deletable d-none mt-3"><i class="fas fa-trash-alt"></i> @lang('Delete')</span>
+								<button class="btn btn-sm btn-danger deletable d-none mt-3" disabled><i class="fas fa-trash-alt"></i> @lang('Delete')</button>
 
 								<div class="invalid-feedback pb-2">
 									@if($e)
