@@ -1,6 +1,7 @@
+<!-- @todo We are not handling redirect backs yet with updated passwords -->
 <!-- $o=Password::class -->
 <x-attribute.layout :edit="$edit ?? FALSE" :new="$new ?? FALSE" :o="$o">
-	@foreach($o->values as $value)
+	@foreach($o->values_old as $value)
 		@if($edit)
 			<div class="input-group has-validation mb-3">
 				<x-form.select id="userpassword_hash_{{$loop->index}}" name="userpassword_hash[]" :value="$o->hash($value)->id()" :options="$helpers" allowclear="false" :disabled="true"/>
@@ -22,7 +23,7 @@
 	<div class="row">
 		<div class="offset-1 col-4 p-2">
 			<span class="p-0 m-0">
-				<button type="button" class="btn btn-sm btn-outline-dark mt-3" data-bs-toggle="modal" data-bs-target="#userpassword_check-modal"><i class="fas fa-user-check"></i> @lang('Check Password')</button>
+				<button id="entry-userpassword-check" type="button" class="btn btn-sm btn-outline-dark mt-3" data-bs-toggle="modal" data-bs-target="#page-modal"><i class="fas fa-user-check"></i> @lang('Check Password')</button>
 			</span>
 		</div>
 	</div>
